FixedColumns examples - FixedColumns examples

# FixedColumns example FixedColumns examples

When making use of DataTables' x-axis scrolling feature (`scrollXDT`), you may wish to fix the left or right most columns in place. This extension for DataTables provides exactly this option (for non-scrolling tables, please use the FixedHeader extension, which can fix headers, footers and columns). Key features include:

- Freezes the left most column to the side of the table
- Option to freeze two or more columns
- Full integration with DataTables' scrolling options